package de.intevation.flys.artifacts.model;

import java.io.Serializable;

import gnu.trove.TDoubleArrayList;


/**
 * This class represents a pool of data triples that consists of 'W', 'Q' and
 * 'KM' data.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class WQKms implements Serializable {

    /** The array that contains the 'W' values.*/
    protected TDoubleArrayList w;

    /** The array that contains the 'Q' values.*/
    protected TDoubleArrayList q;

    /** The array that contains the 'KMs' values.*/
    protected TDoubleArrayList kms;


    public WQKms() {
        this.w   = new TDoubleArrayList();
        this.q   = new TDoubleArrayList();
        this.kms = new TDoubleArrayList();
    }


    /**
     * Adds a new row to this data pool.
     *
     * @param w a W.
     * @param q a Q.
     * @param kms a Kms.
     */
    public void add(double w, double q, double kms) {
        this.w.add(w);
        this.q.add(q);
        this.kms.add(kms);
    }


    /**
     * This method returns a triple of W, Q and Kms in a single 3dim array.
     *
     * @param idx The position of the triple.
     *
     * @return a triple of [W, Q, Kms].
     */
    public double[] get(int idx) {
        return get(idx, new double[3]);
    }

    /**
     * This method returns a triple of W, Q and Kms in a single 3dim array.
     *
     * @param idx The position of the triple.
     * @param dst destination array
     *
     * @return a triple of [W, Q, Kms] in dst.
     */
    public double[] get(int idx, double [] dst) {
        dst[0] = w  .get(idx);
        dst[1] = q  .get(idx);
        dst[2] = kms.get(idx);
        return dst;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
